@@ -597,14 +597,14 @@ void SetPropertyCommand::setProperty( const TQVariant &v, const TQString &curren
 	    if ( formWindow()->isMainContainer( widget ) )
 		formWindow()->setName( v.toCString() );
 	}
-	if ( propName == "name" && widget->inherits( TQACTION_OBJECT_NAME_STRING ) &&
+	if ( propName == "name" && widget->inherits( "TQAction" ) &&
 	     formWindow()->mainContainer() &&
-	     formWindow()->mainContainer()->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) ) {
+	     formWindow()->mainContainer()->inherits( "TQMainWindow" ) ) {
 	    formWindow()->mainWindow()->actioneditor()->updateActionName( (TQAction*)widget );
 	}
-	if ( propName == "iconSet" && widget->inherits( TQACTION_OBJECT_NAME_STRING ) &&
+	if ( propName == "iconSet" && widget->inherits( "TQAction" ) &&
 	     formWindow()->mainContainer() &&
-	     formWindow()->mainContainer()->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) ) {
+	     formWindow()->mainContainer()->inherits( "TQMainWindow" ) ) {
 	    formWindow()->mainWindow()->actioneditor()->updateActionIcon( (TQAction*)widget );
 	}
 	if ( propName == "caption" ) {
@@ -751,9 +751,9 @@ BreakLayoutCommand::BreakLayoutCommand( const TQString &n, FormWindow *fw,
     margin = MetaDataBase::margin( TQT_TQOBJECT(layoutBase) );
     layout = 0;
     if ( lay == WidgetFactory::HBox )
-	layout = new HorizontalLayout( wl, layoutBase, fw, layoutBase, false, layoutBase->inherits( TQSPLITTER_OBJECT_NAME_STRING ) );
+	layout = new HorizontalLayout( wl, layoutBase, fw, layoutBase, false, layoutBase->inherits( "TQSplitter" ) );
     else if ( lay == WidgetFactory::VBox )
-	layout = new VerticalLayout( wl, layoutBase, fw, layoutBase, false, layoutBase->inherits( TQSPLITTER_OBJECT_NAME_STRING ) );
+	layout = new VerticalLayout( wl, layoutBase, fw, layoutBase, false, layoutBase->inherits( "TQSplitter" ) );
     else if ( lay == WidgetFactory::Grid )
 	layout = new GridLayout( wl, layoutBase, fw, layoutBase, TQSize( TQMAX( 5, fw->grid().x()), TQMAX( 5, fw->grid().y()) ), false );
 }
@@ -1605,7 +1605,7 @@ void AddActionToToolBarCommand::execute()
 	toolBar->insertAction( ( (QSeparatorAction*)action )->widget(), action );
 	( (QSeparatorAction*)action )->widget()->installEventFilter( toolBar );
     }
-    if ( !action->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) || ( (TQActionGroup*)action )->usesDropDown()) {
+    if ( !action->inherits( "TQActionGroup" ) || ( (TQActionGroup*)action )->usesDropDown()) {
 	if ( index == -1 )
 	    toolBar->appendAction( action );
 	else
@@ -1620,7 +1620,7 @@ void AddActionToToolBarCommand::execute()
 	    while ( it.current() ) {
 		TQObject *o = it.current();
 		++it;
-		if ( !o->inherits( TQACTION_OBJECT_NAME_STRING ) )
+		if ( !o->inherits( "TQAction" ) )
 		    continue;
 		// ### fix it for nested actiongroups
 		if ( o->inherits( "QDesignerAction" ) ) {
@@ -1650,7 +1650,7 @@ void AddActionToToolBarCommand::unexecute()
     toolBar->removeAction( action );
     action->removeFrom( toolBar );
     TQObject::disconnect( action, TQT_SIGNAL( destroyed() ), toolBar, TQT_SLOT( actionRemoved() ) );
-    if ( !action->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) || ( (TQActionGroup*)action )->usesDropDown()) {
+    if ( !action->inherits( "TQActionGroup" ) || ( (TQActionGroup*)action )->usesDropDown()) {
 	action->removeEventFilter( toolBar );
     } else {
 	TQObjectList clo = action->childrenListObject();
@@ -1659,7 +1659,7 @@ void AddActionToToolBarCommand::unexecute()
 	    while ( it.current() ) {
 		TQObject *o = it.current();
 		++it;
-		if ( !o->inherits( TQACTION_OBJECT_NAME_STRING ) )
+		if ( !o->inherits( "TQAction" ) )
 		    continue;
 		if ( o->inherits( "QDesignerAction" ) ) {
 		    o->removeEventFilter( toolBar );
@@ -1680,7 +1680,7 @@ AddActionToPopupCommand::AddActionToPopupCommand( const TQString &n, FormWindow
 
 void AddActionToPopupCommand::execute()
 {
-    if ( action->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) ) {
+    if ( action->inherits( "TQActionGroup" ) ) {
 	if ( ( (TQActionGroup*)action )->usesDropDown() ) {
 	    action->addTo( popup );
 	    popup->insertAction( index, action );
@@ -1693,7 +1693,7 @@ void AddActionToPopupCommand::execute()
 		while ( it.current() ) {
 		    TQObject *o = it.current();
 		    ++it;
-		    if ( !o->inherits( TQACTION_OBJECT_NAME_STRING ) )
+		    if ( !o->inherits( "TQAction" ) )
 			continue;
 		    QDesignerAction *ac = (QDesignerAction*)o;
 		    popup->insertAction( index + (i++), ac );
@@ -1717,7 +1717,7 @@ void AddActionToPopupCommand::unexecute()
     action->removeFrom( popup );
     popup->removeAction( action );
     TQObject::disconnect( action, TQT_SIGNAL( destroyed() ), popup, TQT_SLOT( actionRemoved() ) );
-    if ( !action->inherits( TQACTIONGROUP_OBJECT_NAME_STRING ) || ( (TQActionGroup*)action )->usesDropDown()) {
+    if ( !action->inherits( "TQActionGroup" ) || ( (TQActionGroup*)action )->usesDropDown()) {
 	action->removeEventFilter( popup );
     } else {
 	TQObjectList clo = action->childrenListObject();
@@ -1726,7 +1726,7 @@ void AddActionToPopupCommand::unexecute()
 	    while ( it.current() ) {
 		TQObject *o = it.current();
 		++it;
-		if ( !o->inherits( TQACTION_OBJECT_NAME_STRING ) )
+		if ( !o->inherits( "TQAction" ) )
 		    continue;
 		if ( o->inherits( "QDesignerAction" ) ) {
 		    o->removeEventFilter( popup );
@@ -1752,7 +1752,7 @@ void AddMenuCommand::execute()
 	formWindow()->unify( TQT_TQOBJECT(popup), n, true );
 	popup->setName( n );
     }
-    if ( !mainWindow->child( 0, TQMENUBAR_OBJECT_NAME_STRING ) ) {
+    if ( !mainWindow->child( 0, "TQMenuBar" ) ) {
 	menuBar = new QDesignerMenuBar( (TQWidget*)mainWindow );
 	menuBar->setName( "menubar" );
     } else {
