@@ -280,7 +280,7 @@ int MetaDataBase::spacing( TQObject *o )
     if ( !o )
         return -1;
     setupDataBase();
-    if ( o->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) )
+    if ( o->inherits( "TQMainWindow" ) )
         o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
     MetaDataBaseRecord *r = db->find( TQT_TQOBJECT(o) );
     if ( !r || !o->isWidgetType() ) {
@@ -318,7 +318,7 @@ int MetaDataBase::margin( TQObject *o )
     if ( !o )
         return -1;
     setupDataBase();
-    if ( o->inherits( TQMAINWINDOW_OBJECT_NAME_STRING ) )
+    if ( o->inherits( "TQMainWindow" ) )
         o = TQT_TQOBJECT(( (TQMainWindow*)o )->centralWidget());
     MetaDataBaseRecord *r = db->find( (void*)o );
     if ( !r || !o->isWidgetType() ) {
