@@ -134,35 +134,35 @@ void WidgetDatabase::setupDataBase( int id )
   /* Designer widgets */
   r = new WidgetDatabaseRecord;
   r->iconName = "pushbutton.xpm";
-  r->name = TQPUSHBUTTON_OBJECT_NAME_STRING;
+  r->name = "TQPushButton";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Push Button");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "toolbutton.xpm";
-  r->name = TQTOOLBUTTON_OBJECT_NAME_STRING;
+  r->name = "TQToolButton";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Tool Button");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "radiobutton.xpm";
-  r->name = TQRADIOBUTTON_OBJECT_NAME_STRING;
+  r->name = "TQRadioButton";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Radio Button");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "checkbox.xpm";
-  r->name = TQCHECKBOX_OBJECT_NAME_STRING;
+  r->name = "TQCheckBox";
   r->group = widgetGroup("Buttons");
   r->toolTip = i18n("Check Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "groupbox.xpm";
-  r->name = TQGROUPBOX_OBJECT_NAME_STRING;
+  r->name = "TQGroupBox";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Group Box");
   r->isContainer = true;
@@ -170,7 +170,7 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "buttongroup.xpm";
-  r->name = TQBUTTONGROUP_OBJECT_NAME_STRING;
+  r->name = "TQButtonGroup";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Button Group");
   r->isContainer = true;
@@ -178,7 +178,7 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "frame.xpm";
-  r->name = TQFRAME_OBJECT_NAME_STRING;
+  r->name = "TQFrame";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Frame");
   r->isContainer = true;
@@ -186,7 +186,7 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "tabwidget.xpm";
-  r->name = TQTABWIDGET_OBJECT_NAME_STRING;
+  r->name = "TQTabWidget";
   r->group = widgetGroup("Containers");
   r->toolTip = i18n("Tabwidget");
   r->isContainer = true;
@@ -194,14 +194,14 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "listbox.xpm";
-  r->name = TQLISTBOX_OBJECT_NAME_STRING;
+  r->name = "TQListBox";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("List Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "listview.xpm";
-  r->name = TQLISTVIEW_OBJECT_NAME_STRING;
+  r->name = "TQListView";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("List View");
   append(r);
@@ -209,7 +209,7 @@ void WidgetDatabase::setupDataBase( int id )
 #if !defined(TQT_NO_ICONVIEW) || defined(UIC)
   r = new WidgetDatabaseRecord;
   r->iconName = "iconview.xpm";
-  r->name = TQICONVIEW_OBJECT_NAME_STRING;
+  r->name = "TQIconView";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("Icon View");
   append(r);
@@ -218,7 +218,7 @@ void WidgetDatabase::setupDataBase( int id )
 #if !defined(TQT_NO_TABLE)
   r = new WidgetDatabaseRecord;
   r->iconName = "table.xpm";
-  r->name = TQTABLE_OBJECT_NAME_STRING;
+  r->name = "TQTable";
   r->group = widgetGroup("Views");
   r->toolTip = i18n("Table");
   append(r);
@@ -228,7 +228,7 @@ void WidgetDatabase::setupDataBase( int id )
   r = new WidgetDatabaseRecord;
   r->iconName = "datatable.xpm";
   r->includeFile = "tqdatatable.h";
-  r->name = TQDATATABLE_OBJECT_NAME_STRING;
+  r->name = "TQDataTable";
   r->group = widgetGroup("Database");
   r->toolTip = i18n("Data Table");
   append(r);
@@ -236,21 +236,21 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "lineedit.xpm";
-  r->name = TQLINEEDIT_OBJECT_NAME_STRING;
+  r->name = "TQLineEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Line Edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "spinbox.xpm";
-  r->name = TQSPINBOX_OBJECT_NAME_STRING;
+  r->name = "TQSpinBox";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Spin Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "dateedit.xpm";
-  r->name = TQDATEEDIT_OBJECT_NAME_STRING;
+  r->name = "TQDateEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Date Edit");
   r->includeFile = "tqdatetimeedit.h";
@@ -258,7 +258,7 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "timeedit.xpm";
-  r->name = TQTIMEEDIT_OBJECT_NAME_STRING;
+  r->name = "TQTimeEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Time Edit");
   r->includeFile = "tqdatetimeedit.h";
@@ -266,7 +266,7 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "datetimeedit.xpm";
-  r->name = TQDATETIMEEDIT_OBJECT_NAME_STRING;
+  r->name = "TQDateTimeEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Date-Time Edit");
   r->includeFile = "tqdatetimeedit.h";
@@ -274,77 +274,77 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "multilineedit.xpm";
-  r->name = TQMULTILINEEDIT_OBJECT_NAME_STRING;
+  r->name = "TQMultiLineEdit";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Multi Line Edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "richtextedit.xpm";
-  r->name = TQTEXTEDIT_OBJECT_NAME_STRING;
+  r->name = "TQTextEdit";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Rich Text Edit");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "combobox.xpm";
-  r->name = TQCOMBOBOX_OBJECT_NAME_STRING;
+  r->name = "TQComboBox";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Combo Box");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "slider.xpm";
-  r->name = TQSLIDER_OBJECT_NAME_STRING;
+  r->name = "TQSlider";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Slider");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "scrollbar.xpm";
-  r->name = TQSCROLLBAR_OBJECT_NAME_STRING;
+  r->name = "TQScrollBar";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Scrollbar");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "dial.xpm";
-  r->name = TQDIAL_OBJECT_NAME_STRING;
+  r->name = "TQDial";
   r->group = widgetGroup("Input");
   r->toolTip = i18n("Dial");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "label.xpm";
-  r->name = TQLABEL_OBJECT_NAME_STRING;
+  r->name = "TQLabel";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Label");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "lcdnumber.xpm";
-  r->name = TQLCDNUMBER_OBJECT_NAME_STRING;
+  r->name = "TQLCDNumber";
   r->group = widgetGroup("Display");
   r->toolTip = i18n("LCD Number");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "progress.xpm";
-  r->name = TQPROGRESSBAR_OBJECT_NAME_STRING;
+  r->name = "TQProgressBar";
   r->group = widgetGroup("Display");
   r->toolTip = i18n("Progress Bar");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "textview.xpm";
-  r->name = TQTEXTVIEW_OBJECT_NAME_STRING;
+  r->name = "TQTextView";
   r->group = widgetGroup("Temp");
   r->toolTip = i18n("Text View");
   append(r);
 
   r = new WidgetDatabaseRecord;
   r->iconName = "textbrowser.xpm";
-  r->name = TQTEXTBROWSER_OBJECT_NAME_STRING;
+  r->name = "TQTextBrowser";
   r->group = widgetGroup("Display");
   r->toolTip = i18n("Text Browser");
   append(r);
@@ -359,19 +359,19 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->name = TQWIDGET_OBJECT_NAME_STRING;
+  r->name = "TQWidget";
   r->isForm = true;
   r->group = widgetGroup("Forms");
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->name = TQDIALOG_OBJECT_NAME_STRING;
+  r->name = "TQDialog";
   r->group = widgetGroup("Forms");
   r->isForm = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->name = TQWIZARD_OBJECT_NAME_STRING;
+  r->name = "TQWizard";
   r->group = widgetGroup("Forms");
   r->isContainer = true;
   append(r);
@@ -383,14 +383,14 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->name = TQLAYOUTWIDGET_OBJECT_NAME_STRING;
+  r->name = "TQLayoutWidget";
   r->group = widgetGroup("Temp");
   r->includeFile = "";
   r->isContainer = true;
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->name = TQSPLITTER_OBJECT_NAME_STRING;
+  r->name = "TQSplitter";
   r->group = widgetGroup("Temp");
   r->includeFile = "tqsplitter.h";
   r->isContainer = true;
@@ -419,7 +419,7 @@ void WidgetDatabase::setupDataBase( int id )
 
   r = new WidgetDatabaseRecord;
   r->iconName = "";
-  r->name = TQMAINWINDOW_OBJECT_NAME_STRING;
+  r->name = "TQMainWindow";
   r->includeFile = "tqmainwindow.h";
   r->group = widgetGroup("Temp");
   r->isContainer = true;
@@ -427,7 +427,7 @@ void WidgetDatabase::setupDataBase( int id )
 
 #ifndef TQT_NO_SQL
   r = new WidgetDatabaseRecord;
-  r->name = TQDATABROWSER_OBJECT_NAME_STRING;
+  r->name = "TQDataBrowser";
   r->includeFile = "tqdatabrowser.h";
   r->group = widgetGroup("Database");
   r->toolTip = "Data Browser";
@@ -436,7 +436,7 @@ void WidgetDatabase::setupDataBase( int id )
   append(r);
 
   r = new WidgetDatabaseRecord;
-  r->name = TQDATAVIEW_OBJECT_NAME_STRING;
+  r->name = "TQDataView";
   r->includeFile = "tqdataview.h";
   r->group = widgetGroup("Database");
   r->toolTip = "Data View";
@@ -849,7 +849,7 @@ TQString WidgetDatabase::createWidgetName( int id )
 {
     setupDataBase( id );
     TQString n = className( id );
-    if ( n == TQLAYOUTWIDGET_OBJECT_NAME_STRING )
+    if ( n == "TQLayoutWidget" )
 	n = "Layout";
     if ( n[ 0 ] == 'Q' )
 	n = n.mid( 1 );
@@ -871,7 +871,7 @@ int WidgetDatabase::idFromClassName( const TQString &name )
     if ( i )
 	return *i;
     if ( name == "FormWindow" )
-	return idFromClassName( TQLAYOUTWIDGET_OBJECT_NAME_STRING );
+	return idFromClassName( "TQLayoutWidget" );
 #ifdef UIC
     setupDataBase( -2 );
     i = className2Id->find( name );
