@@ -353,7 +353,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
       byteDataStream << params[i++].toDouble();
     else if (*it == "bool")
       byteDataStream << (bool)params[i++].toInt();
-    else if (*it == TQSTRINGLIST_OBJECT_NAME_STRING)
+    else if (*it == "TQStringList")
       if (params[i].toString().find('\n') != -1)
         byteDataStream << TQStringList::split("\n", params[i++].toString(), true);
       else
@@ -371,7 +371,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
     return ParseNode();
   }
   TQDataStream byteReplyStream(byteReply, IO_ReadOnly);
-  if (replyType == TQSTRING_OBJECT_NAME_STRING)
+  if (replyType == "TQString")
   {
     TQString text;
     byteReplyStream >> text;
@@ -389,7 +389,7 @@ static ParseNode f_dcop(Parser*, const ParameterList& params)
     byteReplyStream >> b;
     return b;
   }
-  else if (replyType == TQSTRINGLIST_OBJECT_NAME_STRING)
+  else if (replyType == "TQStringList")
   {
     TQStringList text;
     byteReplyStream >> text;
