@@ -1680,7 +1680,7 @@ void KDockManager::activate()
         obj->show();
     }
   }
-  if ( !main->inherits(TQDIALOG_OBJECT_NAME_STRING) ) main->show();
+  if ( !main->inherits("TQDialog") ) main->show();
 }
 
 bool KDockManager::eventFilter( TQObject *obj, TQEvent *event )
@@ -3046,7 +3046,7 @@ void KDockArea::resizeEvent(TQResizeEvent *rsize)
 #ifndef NO_KDE2
 //    kdDebug(282)<<"KDockArea::resize"<<endl;
 #endif
-    TQObjectList *list=queryList(TQWIDGET_OBJECT_NAME_STRING,0,false);
+    TQObjectList *list=queryList("TQWidget",0,false);
 
     TQObjectListIt it( *list ); // iterate over the buttons
     TQObject *obj;
